==> haskell-lifted-async-0.10.0.4-27-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-lifted-async.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lifted-async
version: 0.10.0.4
id: lifted-async-0.10.0.4-5ammqedbcBa9neyDzTNVv6
key: lifted-async-0.10.0.4-5ammqedbcBa9neyDzTNVv6
license: BSD-3-Clause
copyright: Copyright (C) 2012-2019 Mitsutoshi Aoe
maintainer: Mitsutoshi Aoe <me@maoe.name>
author: Mitsutoshi Aoe
homepage: https://github.com/maoe/lifted-async
synopsis: Run lifted IO operations asynchronously and wait for their results
description:
    This package provides IO operations from @async@ package lifted to any
    instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.
category: Concurrency
abi: 9d7c7db58f4c291ed2f63fa87a954633
exposed: True
exposed-modules:
    Control.Concurrent.Async.Lifted
    Control.Concurrent.Async.Lifted.Safe
import-dirs: /usr/lib/ghc-8.6.5/site-local/lifted-async-0.10.0.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/lifted-async-0.10.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/lifted-async-0.10.0.4
hs-libraries: HSlifted-async-0.10.0.4-5ammqedbcBa9neyDzTNVv6
depends:
    async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG base-4.12.0.0
    constraints-0.11.2-4EdyX7dshTEIpPnTgXiL7T
    lifted-base-0.2.3.12-AptnLlCSRcTHtTYEKD9GFf
    monad-control-1.0.2.3-EQU08Q5uVAI5Qyu4idMrsU
    transformers-base-0.4.5.2-LMjNLq6jsSj2JdftiUxIvR
haddock-interfaces: /usr/share/doc/haskell-lifted-async/html/lifted-async.haddock
haddock-html: /usr/share/doc/haskell-lifted-async/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lifted-async-0.10.0.4-28-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-lifted-async.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lifted-async
version: 0.10.0.4
id: lifted-async-0.10.0.4-3z4aSues7zHE0hviClHIIe
key: lifted-async-0.10.0.4-3z4aSues7zHE0hviClHIIe
license: BSD-3-Clause
copyright: Copyright (C) 2012-2019 Mitsutoshi Aoe
maintainer: Mitsutoshi Aoe <me@maoe.name>
author: Mitsutoshi Aoe
homepage: https://github.com/maoe/lifted-async
synopsis: Run lifted IO operations asynchronously and wait for their results
description:
    This package provides IO operations from @async@ package lifted to any
    instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.
category: Concurrency
abi: a0c3c352d1ac36ca2609128baa91ac3e
exposed: True
exposed-modules:
    Control.Concurrent.Async.Lifted
    Control.Concurrent.Async.Lifted.Safe
import-dirs: /usr/lib/ghc-8.6.5/site-local/lifted-async-0.10.0.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/lifted-async-0.10.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/lifted-async-0.10.0.4
hs-libraries: HSlifted-async-0.10.0.4-3z4aSues7zHE0hviClHIIe
depends:
    async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG base-4.12.0.0
    constraints-0.11.2-88kGqmIOzi4DqJECoxnbEu
    lifted-base-0.2.3.12-B68iwk5BNXFLXLdjdYGHmp
    monad-control-1.0.2.3-EKrTS47Oi8IKd1pTyskzd3
    transformers-base-0.4.5.2-KWttVZ7nb0vsLFTQBq79t
haddock-interfaces: /usr/share/doc/haskell-lifted-async/html/lifted-async.haddock
haddock-html: /usr/share/doc/haskell-lifted-async/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
